@@ -5,6 +5,7 @@ from source_tab import create_source_tab
 from geometry_tab import create_geometry_tab
 from regularmesh_tab import create_regularmesh_tab
 from weightwindows_tab import create_weightwindow_tab
+from dagmcslice_tab import create_dagmcslice_tab
 from pathlib import Path
 
 # assigns a minimal cross section xml file
@@ -18,11 +19,13 @@ def main():
 
     header()
 
-    geometry_tab, source_tab, regularmesh_tab, weightwindow_tab = st.tabs(
-        ["🖼 Geometry plot", "✴️ Source Plot", "🧊 Regular Mesh Plot", "🪟 Weight Windows Plot"]
+    geometry_tab, dagmcslice_tab, source_tab, regularmesh_tab, weightwindow_tab = st.tabs(
+        ["🖼 Geometry plot", "🍕 DAGMC Slice Plot", "✴️ Source Plot", "🧊 Regular Mesh Plot", "🪟 Weight Windows Plot"]
     )
     with geometry_tab:
         create_geometry_tab()
+    with dagmcslice_tab:
+        create_dagmcslice_tab()
     with source_tab:
         create_source_tab()
     with regularmesh_tab:
